@@ -46,6 +46,13 @@ tenable:
     - high
     - critical
 
+  # The severity prioritization mapping.
+  severity_prioritization:
+    critical: 1
+    high: 2
+    medium: 3
+    low: 4
+
   # How many days back should we go?
   tio_age: 30
 
@@ -164,21 +171,21 @@ issue_default_fields:
   description:
     Task:
       - name: Description
-        tio_field: '{vuln[plugin.description]}'
-        tsc_field: '{vuln[description]}'
+        tio_field: '{vuln[plugin.description]} '
+        tsc_field: '{vuln[description]} '
       - name: Solution
-        tio_field: '{vuln[plugin.solution]}'
-        tsc_field: '{vuln[solution]}'
+        tio_field: '{vuln[plugin.solution]} '
+        tsc_field: '{vuln[solution]} '
     Sub-task:
       - name: Description
-        tio_field: '{vuln[plugin.description]}'
-        tsc_field: '{vuln[description]}'
+        tio_field: '{vuln[plugin.description]} '
+        tsc_field: '{vuln[description]} '
       - name: Solution
-        tio_field: '{vuln[plugin.solution]}'
-        tsc_field: '{vuln[solution]}'
+        tio_field: '{vuln[plugin.solution]} '
+        tsc_field: '{vuln[solution]} '
       - name: Output
-        tio_field: '{vuln[output]}'
-        tsc_field: '{vuln[pluginOutput]}'
+        tio_field: '{vuln[output]} '
+        tsc_field: '{vuln[pluginOutput]} '
 
 
 # Screen definition section
@@ -210,6 +217,7 @@ screen:
       - Vulnerability Port
       - Vulnerability Protocol
       - Patch Publication Date
+      - Finding Severity
     Asset:
       - Tenable Asset UUID
       - Tenable Asset Tags
@@ -337,6 +345,14 @@ fields:
     tio_field: plugin.risk_factor
     tsc_field: severity.name
 
+  - jira_field: Finding Severity
+    type: readonlyfield
+    searcher: textsearcher
+    issue_type:
+      - Sub-task
+    tio_field: severity
+    tsc_field: severity.name
+
   # Vulnerability Instance fields
   - jira_field: Tenable Asset UUID
     type: labels
